parser

package
v0.0.0-...-7aee52b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 28, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package parser reads Writ source into runtime values and pretty-prints it.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Format

func Format(src string) (string, error)

Format pretty-prints src. A trailing newline is added when src is not empty.

func Incomplete

func Incomplete(err error) bool

Incomplete reports whether a Parse error means src needs more input (unclosed list, map, string, tick symbol, or quote).

func Parse

func Parse(src string) ([]runtime.Value, error)

Parse reads src into top-level forms. Comments are included.

Types

This section is empty.

Jump to